@@ -6,13 +6,13 @@ pdftools Package.
 
 :created on 2018-04-14 20:35:21
 :last modified by:   Stefan Lehmann
-:last modified time: 2018-05-04 14:19:05
+:last modified time: 2018-10-28 16:57:24
 
 """
-__version__ = "1.1.3"
+__version__ = "2.0.0"
 
 
-from pdftools.pdftools import (  # noqa: F401
+from .pdftools import (
     pdf_merge,
     pdf_rotate,
     pdf_split,
